"""
 -*-coding:utf-8 -*-
----------------------------------------------------------------------------
--ProjectName:   pytest
--FileName:      test_bpm.py
--Author:        Lin
--Datetime:      2024/11/05 下午7:11
--Description:   设置日志
-----------------(❁´◡`❁)---------------------------------------------------
"""
import logging
import os
import time
import functools

def api_log():
    # 创建Logger对象    root
    logger = logging.getLogger()
    # 设置级别
    logger.level = logging.INFO
    # 日志文件存放的路径
    log_dir_path = os.path.join(os.path.join(os.path.dirname(__file__), "report"), "log")
    log_file_name = time.strftime("%Y-%m-%d %H-%M-%S", time.localtime()) + ".log"
    log_path = os.path.join(log_dir_path, log_file_name)
    # 创建日志文件的Handler对象
    handler = logging.FileHandler(filename=log_path, mode="a", encoding="utf-8")
    # 设置日志显示的格式
    formatter = logging.Formatter('%(asctime)s - %(filename)s[line:%(lineno)d] - %(levelname)s: %(message)s')
    # 给Handler设置日志的格式
    handler.setFormatter(formatter)
    # 给Logger添加Handler对象
    logger.addHandler(handler)
    return logger

log = api_log()


def logor(func_name):
    @functools.wraps(func_name)
    def inner(*args, **kwargs):
        log.info(f"py文件为{func_name.__code__.co_filename}，第{func_name.__code__.co_firstlineno}行，"
                 f"执行的功能为{func_name.__name__}，功能描述为{func_name.__doc__}，形参为{args}或{kwargs}")
        try:
            result = func_name(*args, **kwargs)
        except Exception as e:
            log.error(
                f"py文件为{func_name.__code__.co_filename}，第{func_name.__code__.cofirstlineno}行，错误类型{type(e)}，错误描述{e}，"
                f"执行的功能为{func_name.__name__}，功能描述为{func_name.__doc__}，形参为{args}或{kwargs}")
            raise e
        else:
            return result
    return inner