"""
 -*-coding:utf-8 -*- 
----------------------------------------------------------------------------
--ProjectName:   pytest
--FileName:      test_bpm.py
--Author:        Lin
--Datetime:      2024/11/05 下午7:11
--Description:  读取excel文件
-----------------(❁´◡`❁)---------------------------------------------------
"""
import openpyxl

from APIAutomaticTesting import log, logor
from APIAutomaticTesting.data_config.settings import *
from APIAutomaticTesting.common.read_basic_ini import ReadBasicIni
from APIAutomaticTesting.common.read_user_ini import ReadUserIni
from APIAutomaticTesting.common.read_json import read_json


class ReadExcel:
    @logor
    def __init__(self, user):
        """读取所有的json文件，获取excel的工作簿和工作表"""
        # 读取指定用户的ini文件
        ini = ReadUserIni(user)

        # 获取指定用户的存放数据的json文件路径
        case_data_path = ini.get_file_path("case")
        expect_data_path = ini.get_file_path("expect")
        sql_data_path = ini.get_file_path("sql")

        self.case_data_dict = read_json(case_data_path)
        self.expect_data_dict = read_json(expect_data_path)
        self.sql_data_dict = read_json(sql_data_path)

        # 获取指定用户的excel文件路径
        excel_path = ini.get_file_path("excel")
        # 获取指定用户的工作表名称
        table_name = ini.get_table_name("name")

        try:
            wb = openpyxl.load_workbook(excel_path)
            self.ws = wb[table_name]
        except Exception as e:
            raise e

    @logor
    def __get_cell_value(self, column: str, row: int) -> str:
        """获取指定单元格数据"""
        try:
            cell_value = self.ws[column+str(row)].value
        except Exception as e:
            raise e
        else:
            if cell_value is None:
                return None
            elif cell_value.strip():
                return cell_value.strip()

    @logor
    def module_name(self, row):
        """根据行号，获取模块名称"""
        return self.__get_cell_value("B", row)

    @logor
    def api_name(self, row):
        """根据行号，获取接口名称"""
        return self.__get_cell_value("c", row)

    @logor
    def case_title(self, row):
        """根据行号，获取用例的标题"""
        return (self.__get_cell_value("D", row))

    @logor
    def case_level(self, row):
        """根据行号，获取用例的等级"""
        return self.__get_cell_value("e", row)

    @logor
    def req_method(self, row):
        """根据行号，获取用例的请求方法"""
        return self.__get_cell_value("f", row)

    @logor
    def req_url(self, row):
        """根据行号，获取用例的请求url"""
        path = self.__get_cell_value("g", row)
        if path:
            # 创建ReadBasicIni类对象，调用get_host获取被测系统的域名，在和接口路径拼接完整的url
            return ReadBasicIni().get_host("bpm") + path

    @logor
    def req_mime(self, row):
        """根据行号，获取用例的请求媒体类型"""
        mime = self.__get_cell_value("h", row)
        if mime:
            return mime.lower()

    @logor
    def case_data(self, row):
        """根据行号，获取用例数据"""
        case_data_key = self.__get_cell_value("i", row)
        module_name = self.module_name(row)
        api_name = self.api_name(row)
        if case_data_key and module_name and api_name:
            return self.case_data_dict[module_name][api_name][case_data_key]

    @logor
    def expect_data(self, row):
        """根据行号，获取期望数据"""
        expect_data_key = self.__get_cell_value("j", row)
        module_name = self.module_name(row)
        api_name = self.api_name(row)
        if expect_data_key and module_name and api_name:
            return self.expect_data_dict[module_name][api_name][expect_data_key]

    @logor
    def sql_type(self, row):
        """根据行号，获取sql语句类型"""
        value = self.__get_cell_value("k", row)
        if value:
            return value.lower()

    @logor
    def sql_data(self, row):
        """根据行号，获取sql语句"""
        sql_data_key = self.__get_cell_value("l", row)
        module_name = self.module_name(row)
        api_name = self.api_name(row)
        if sql_data_key and module_name and api_name:
            return self.sql_data_dict[module_name][api_name][sql_data_key]

    @logor
    def update_key(self, row):
        """根据行号，获取用例的更新的key"""
        return self.__get_cell_value("m", row)

    def get_data(self):
        """将测试使用到的数据存放在二维列表中"""
        list_data = []
        for row in range(2, self.ws.max_row+1):
            method = self.req_method(row)
            url = self.req_url(row)
            mime = self.req_mime(row)
            case_data = self.case_data(row)
            expect_data = self.expect_data(row)
            sql_type = self.sql_type(row)
            sql_data = self.sql_data(row)
            update_key = self.update_key(row)
            module = self.module_name(row)
            api = self.api_name(row)
            title = self.__get_cell_value("D", row)
            level = self.__get_cell_value("E", row)
            if method and url and expect_data:
                list_data.append([method, url, mime, case_data, expect_data, sql_type, sql_data, update_key, module, api, title, level])
        else:
            return list_data


if __name__ == '__main__':
    excel = ReadExcel("Kumiko")
    print(excel.get_data())